# weblogin

`weblogin` is a Python package that allows transparent logging in to web UIs to 
access their unofficial APIs.

`/doc` contains the source for the documented source code.

`/src` contains the literate package source. Must be compiled to Python code 
using NOWEB. Simply run `make`.

`/tests` contains tests. Run `make` in that directory to run them.
